summaryrefslogtreecommitdiffstats
path: root/lib/kotext/KoTextViewIface.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kotext/KoTextViewIface.h')
-rw-r--r--lib/kotext/KoTextViewIface.h76
1 files changed, 38 insertions, 38 deletions
diff --git a/lib/kotext/KoTextViewIface.h b/lib/kotext/KoTextViewIface.h
index cee86f06..1d993932 100644
--- a/lib/kotext/KoTextViewIface.h
+++ b/lib/kotext/KoTextViewIface.h
@@ -23,8 +23,8 @@
#include <KoDocumentIface.h>
#include <dcopref.h>
-#include <qstring.h>
-#include <qcolor.h>
+#include <tqstring.h>
+#include <tqcolor.h>
#include <KoRichText.h>
#include <koffice_export.h>
class KoTextView;
@@ -39,7 +39,7 @@ k_dcop:
void insertSoftHyphen();
void insertNonbreakingSpace();
void insertNonbreakingHyphen();
- void insertText( const QString &text );
+ void insertText( const TQString &text );
void newParagraph();
void setBold(bool b);
void setItalic(bool on);
@@ -49,14 +49,14 @@ k_dcop:
void setPointSize( int s );
void setTextSubScript(bool on);
void setTextSuperScript(bool on);
- void setUnderlineColor( const QColor & color );
+ void setUnderlineColor( const TQColor & color );
void setDefaultFormat();
void setRelativeTextSize( double _size);
- QColor textColor() const;
- QString textFontFamily()const;
- QColor textBackgroundColor()const;
- QColor textUnderlineColor() const;
+ TQColor textColor() const;
+ TQString textFontFamily()const;
+ TQColor textBackgroundColor()const;
+ TQColor textUnderlineColor() const;
bool textDoubleUnderline() const;
bool textItalic() const;
@@ -70,10 +70,10 @@ k_dcop:
bool wordByWord() const;
void setWordByWord( bool _b );
- void setTextColor(const QColor &color);
- void setTextBackgroundColor(const QColor &);
+ void setTextColor(const TQColor &color);
+ void setTextBackgroundColor(const TQColor &);
void setAlign(int align);
- void setAlign(const QString &);
+ void setAlign(const TQString &);
bool isReadWrite() const ;
void setReadWrite( bool b );
@@ -114,16 +114,16 @@ k_dcop:
void setSpaceAfterParag(double pt);
// apply border, for the futur add border style
- void setLeftBorder( const QColor & c,double width );
- void setRightBorder( const QColor & c,double width );
+ void setLeftBorder( const TQColor & c,double width );
+ void setRightBorder( const TQColor & c,double width );
- void setTopBorder( const QColor & c,double width );
- void setBottomBorder(const QColor & c,double width );
+ void setTopBorder( const TQColor & c,double width );
+ void setBottomBorder(const TQColor & c,double width );
- void setLeftBorderColor( const QColor & c );
- void setRightBorderColor( const QColor & c );
- void setTopBorderColor( const QColor & c);
- void setBottomBorderColor(const QColor & c );
+ void setLeftBorderColor( const TQColor & c );
+ void setRightBorderColor( const TQColor & c );
+ void setTopBorderColor( const TQColor & c);
+ void setBottomBorderColor(const TQColor & c );
void setLeftBorderWidth( double _witdh );
void setRightBorderWidth( double _witdh );
void setTopBorderWidth( double _witdh );
@@ -136,43 +136,43 @@ k_dcop:
double topBorderWidth() const;
double bottomBorderWidth() const;
- QColor leftBorderColor() const ;
- QColor rightBorderColor() const;
- QColor topBorderColor() const;
- QColor bottomBorderColor() const;
+ TQColor leftBorderColor() const ;
+ TQColor rightBorderColor() const;
+ TQColor topBorderColor() const;
+ TQColor bottomBorderColor() const;
- void changeCaseOfText( const QString & caseType);
+ void changeCaseOfText( const TQString & caseType);
bool isALinkVariable() const;
//return false if there is not a link
- bool changeLinkVariableUrl( const QString & _url) const;
+ bool changeLinkVariableUrl( const TQString & _url) const;
//return false if there is not a link
- bool changeLinkVariableName( const QString & _name) const;
+ bool changeLinkVariableName( const TQString & _name) const;
- //be carefull these functions return QString::null when there is not
+ //be carefull these functions return TQString() when there is not
//a variable
- QString linkVariableUrl( ) const;
- QString linkVariableName( ) const;
+ TQString linkVariableUrl( ) const;
+ TQString linkVariableName( ) const;
bool isANoteVariable() const ;
- QString noteVariableText() const;
+ TQString noteVariableText() const;
//return false if there is not a note variable
- bool setNoteVariableText(const QString & note) const;
+ bool setNoteVariableText(const TQString & note) const;
void removeComment();
- QString underlineStyle() const;
- QString strikeOutStyle()const;
+ TQString underlineStyle() const;
+ TQString strikeOutStyle()const;
- void setLanguage(const QString & _lang);
- QString language() const;
- void addBookmarks(const QString &url);
+ void setLanguage(const TQString & _lang);
+ TQString language() const;
+ void addBookmarks(const TQString &url);
void copyLink();
void removeLink();
void copyTextOfComment();
- QString fontAttibute()const;
+ TQString fontAttibute()const;
private:
KoTextView *m_textView;
protected:
- //QString lineStyleToString( KoTextFormat::LineStyle _style ) const;
+ //TQString lineStyleToString( KoTextFormat::LineStyle _style ) const;
};
#endif